@@ -1,21 +1,21 @@
-# sh script for running various tests of abinis and abinip
+# sh script for running various tests of abinit
 # Actually run different instances of the Run script.
 # See the latter script for more information.
 
-# Copyright (C) 2002-2009 ABINIT group (XG,LSi,YPouillon)
+# Copyright (C) 2002-2010 ABINIT group (XG,LSi,YPouillon)
 # This file is distributed under the terms of the
 # GNU General Public License, see ~abinit/COPYING
 # or http://www.gnu.org/copyleft/gpl.txt .
 # For the initials of contributors, see ~abinit/doc/developers/contributors.txt .
 #
 # Usage under sh-shell:
-# ( drive-parallel-tests machine_name sets [cases] ) >& log_file
+# ( drive-parallel-tests machine_name testdir sets [cases] ) >& log_file
 #
 # For example :
-# ( drive-parallel-tests sleepy A ) >& log_file
-# ( drive-parallel-tests sleepy A-D ) >& log_file
-# ( drive-parallel-tests sleepy A 0 ) >& log_file
-# ( drive-parallel-tests sleepy A 1-2 ) >& log_file
+# ( drive-parallel-tests sleepy mpiio A ) >& log_file
+# ( drive-parallel-tests sleepy paral A-D ) >& log_file
+# ( drive-parallel-tests sleepy paral A 0 ) >& log_file
+# ( drive-parallel-tests sleepy paral A 1-2 ) >& log_file
 #
 # The list of allowed machine names is mentioned in the run-parallel-tests
 # script. More information on the arguments is also provided in the same script.
@@ -28,10 +28,10 @@ my_name="drive-parallel-tests"
 my_cnffile="tests.env"
 
 # Check arguments
-if test "${#}" -lt "2"; then
-  echo "Usage: ${my_name} machine_name sets [cases]"
+if test "${#}" -lt "3"; then
+  echo "Usage: ${my_name} machine_name testdir sets [cases]"
   echo ""
-  echo "Two arguments must be provided giving machine name and mode"
+  echo "Three arguments must be provided giving machine name, testdir, sets"
   exit 0
 fi
 
@@ -45,8 +45,14 @@ fi
 
 # Finish init
 machine_name="${1}"
+testdir_name="${2}"
 run_parallel_tests="${PERL} ${abinit_rundir}/run-parallel-tests.pl"
 
-cd "${abinit_outdir}/paral"
-(${run_parallel_tests} ${machine_name} ${2} ${3}) 2>&1 1> ,,log
+#DEBUG
+echo "${abinit_outdir}/${2}"
+echo "${run_parallel_tests} ${machine_name} ${testdir_name} ${3} ${4}"
+#ENDDEBUG
+
+cd "${abinit_outdir}/${2}"
+(${run_parallel_tests} ${machine_name} ${testdir_name} ${3} ${4}) 1>tmp-log 2>&1
 
