@@ -4,7 +4,7 @@
 # Object: compare 2 output files from ABINIT line by line with arithmetic
 # comparisons of floating point substrings
 #
-# Copyright (C) 1999-2009 ABINIT group (LSi,XG)
+# Copyright (C) 1999-2010 ABINIT group (LSi,XG)
 # This file is distributed under the terms of the
 # GNU General Public License, see ~abinit/COPYING
 # or http://www.gnu.org/copyleft/gpl.txt .
@@ -175,7 +175,7 @@ while (1) {
     last;
     }
   if ($ldc1 ne $ldc2) {
-    print "The diff analysis cannot be pursued : the command sign differ.";
+    print "The diff analysis cannot be pursued : the leading characters differ.";
     print "File 1, line $lnm1, $ign1 ignored, character:$ldc1";
     print "File 2, line $lnm2, $ign2 ignored, character:$ldc2\n";
     &summary(36);
@@ -200,6 +200,7 @@ $lnm2 = 0;
 $diffcnt = 0;
 $contextprv = '';
 while (1) {
+  $diffcntfl = 0;
   while ($lin1 = <FILEIN1>) {	# read next line from file 1
     $lnm1 ++;		# bump line counter
     $ldc1 = substr($lin1,0,1);	# leading character
@@ -217,6 +218,21 @@ while (1) {
     print "Internal error at lines $lnm1 $lnm2";
     &summary(96);
     }
+# YP: ignore differences caused by MPI extra output
+# FIXME: this is probably quite dirty :-s
+  $lin1 =~ s/ by node([ ]+)([0-9]+)//;
+  $lin2 =~ s/ by node([ ]+)([0-9]+)//;
+  $lin1 =~ s/_P-[0-9]{4}_(EIG)/_$1/;
+  $lin2 =~ s/_P-[0-9]{4}_(EIG)/_$1/;
+# DC: in XML file, add a '.' sign at start of line for the timeInfo element.
+  if ((index $lin1, "timeInfo") ge 0) {
+    $lin1 = '.'.$lin1;
+    $ldc1 = '.'
+  }
+  if ((index $lin2, "timeInfo") ge 0) {
+    $lin2 = '.'.$lin2;
+    $ldc2 = '.'
+  }
   $same = 1;		# assume lines are similar
 # + command character
   if($ldc1 eq '+') {
@@ -241,7 +257,7 @@ while (1) {
       $same = 0;
       $diffcnt ++;
       }
-    else { 
+    else {
       if ($ldc1 eq ':') {	# no floating point tolerance - characters
         $tolerance = 0;
         }
@@ -321,13 +337,20 @@ while (1) {
 # Error: both tolerance criteria exceeded
                 print 'DBG flttoler',$lnm1,$i if($debug >= 1);
                 $same = 0;
-                $diffcnt ++;
-                $maxAbsDif = $difflt if ($difflt > $maxAbsDif);
+#jmb                $diffcnt ++;
+  		$diffcntfl ++;
+		if ($difflt > $maxAbsDif) {
+                  $maxAbsDif = $difflt;
+		  $linAbsDif = $lnm1;
+		}
                 if ($sumflt > 0.0e0) {
                   $diffltrel = $difflt / $sumflt;
-                  $maxRelDif = $diffltrel if ($diffltrel > $maxRelDif);
-                  }
-                last NEXTFIELD;
+		  if ($diffltrel > $maxRelDif) {
+                    $maxRelDif = $diffltrel;
+		    $linRelDif = $lnm1;
+		  }
+                }
+#jmb                last NEXTFIELD;
                 }
               else {
                 $len = length($remainder);
@@ -354,6 +377,7 @@ while (1) {
             }
           }
         }	# end for ($i
+	if ($diffcntfl > 0) { $diffcnt ++; };
       }
     }
 #
@@ -450,6 +474,6 @@ sub summary {
     exit 0;
     }
 #
-  print "Summary $label : different lines= $diffcnt , max discrepancies absolute= $maxAbsDif , relative= $maxRelDif";
+  print "Summary $label : different lines= $diffcnt , max discrepancies absolute= $maxAbsDif (l.$linAbsDif), relative= $maxRelDif (l.$linRelDif)";
   exit 4;
   }
