@@ -1,7 +1,7 @@
-# Script for testing abinis in charge (TC = Test Charge)
+# Script for testing abinit in charge (TC = Test Charge)
 # Before running this script, read README in this directory.
 
-# Copyright (C) 2000-2009 ABINIT group (XG,LSi)
+# Copyright (C) 2000-2010 ABINIT group (XG,LSi)
 # This file is distributed under the terms of the
 # GNU General Public License, see ~abinit/COPYING
 # or http://www.gnu.org/copyleft/gpl.txt .
@@ -33,7 +33,7 @@ else
 fi
 
 # Set codename for sequential version
-CODE_SEQ="${abinit_bindir}/abinis"
+CODE_SEQ="${abinit_bindir}/abinit"
 # Set pseudopotential directory
 PSPS="${abinit_pspdir}"
 # Define the pseudopotential
@@ -53,7 +53,7 @@ echo "testing the Abinit code on the $MACH platform"
 
 YYMMDD=`date "+DATE %Y%m%d" | cut -d" " -f2`
 
-WORK_DIR=,,"$MACH"_"$YYMMDD"
+WORK_DIR="tmp-${MACH}_${YYMMDD}"
 if test ! -d $WORK_DIR
 then
   mkdir $WORK_DIR
