@@ -1,7 +1,6 @@
 #!/bin/sh
 #
-# Copyright (C) 2005-2009 ABINIT Group (Yann Pouillon)
-# All rights reserved.
+# Copyright (C) 2005-2010 ABINIT Group (Yann Pouillon)
 #
 # This file is part of the ABINIT software package. For license information,
 # please see the COPYING file in the top-level directory of the ABINIT source
@@ -23,7 +22,7 @@ else
 fi
 
 # Finish init
-my_outdir="${abinit_outdir}/netcdf/,,`hostname`_`date '+%Y%m%d'`"
+my_outdir="${abinit_outdir}/netcdf/tmp-`hostname`_`date '+%Y%m%d'`"
 
 mkdir -p ${my_outdir} && cd ${my_outdir} && ${abinit_bindir}/abinetcdf
 exit ${?}
