@@ -1,7 +1,7 @@
-# Script for running various tests of abinip, the parallel version of abinit
+# Script for running various tests of the parallel version of abinit
 # Before running this script, read README in this directory.
 
-# Copyright (C) 1998-2009 ABINIT group (XG,LSi)
+# Copyright (C) 1998-2010 ABINIT group (XG,LSi)
 # This file is distributed under the terms of the
 # GNU General Public License, see ~abinit/COPYING
 # or http://www.gnu.org/copyleft/gpl.txt .
@@ -39,21 +39,41 @@ $abinit_rundir = $ENV{'abinit_rundir'};
 $abinit_pspdir = $ENV{'abinit_pspdir'};
 $abinit_inpdir = $ENV{'abinit_inpdir'};
 $abinit_outdir = $ENV{'abinit_outdir'};
+$nightly_bindir = $ENV{'nightly_bindir'};
 $PERL = $ENV{'PERL'};
+$PERL = 'perl' if ($PERL eq '');
+$config_mpirun = $ENV{'MPI_RUNNER'};
+
+# load reportdiff lib
+# import lib
+$top_testdir=$abinit_inpdir;
+do "$top_testdir/Scripts/reportdiff.pl";
+
+# Timeout support
+#
+# This is required for nightly builds, because e.g. binaries built
+# with ifort 10.0 make the process hang forever when they crash.
+$timeout = $ENV{'timeout'};
+$timeout = '0' if ($timeout eq '');
 
 $, = ' ';               # set output field separator
 $\ = "\n";              # set output record separator
 #
-@MachList=('t3e','sgi','tux','vpp','hp','compaq_es40','ibm_44p','sr8k','mpd','sun','dummy','test','spinoza','fock','max','lemaitre','sleepy(-compilo)','pwrg4','mpich2','generic','chum(-compilo)', 'cea', 'bigmac','green','chpit-intel11','chpit-gcc44');
+@MachList=('t3e','sgi','tux','vpp','compaq_es40','magerit','sr8k','mpd','sun','test','spinoza','fock','max','lemaitre','sleepy(-compilo)','pwrg4','mpich2','generic','chum(-compilo)','cea','chpit-intel11','chpit-gcc44','testf-gcc43','testf-gcc44','bigmac','bigmac-g95','bigmac-gcc44','green','green-gcc42','green-g95','config','coba2-gcc44','coba2-intel','buda_mpich2','buda-gcc43_openmpi','buda-gcc44_openmpi','buda-gcc45_openmpi', 'buda-intel11', 'inca', 'shiva', 'ibm6_mpich2', 'ibm6_openmpi','ibm6', 'win32_mpich2','littlebuda');
 @CompiloList = ('g95','pgi','gcc41','gcc42','gcc43','pathscale','intel','intel10','open64','sun');
-@Cases = ('0','1','2','4','10');
+@Cases = ('1','2','4','10');
 $debug = 2;
+$POE = 0;
 # Check whether a machine name is provided
 if ($#ARGV < 1) {
   print 'At least, two arguments must be provided giving machine name and set number';
   print "Choose among :@MachList" if ($#ARGV < 0);
   exit 16;
 	}
+print $ARGV[0];
+print $ARGV[1];
+print $ARGV[2];
+print $ARGV[3];
 #
 $UNIXSLASH = '/';	# unix subdirectory delimitor in file paths (octal 057)
 $DOSSLASH = '\\';	# subdirectory delimitor in DOS file paths (\ escaped)
@@ -61,13 +81,26 @@ $DOSSLASH = '\\';	# subdirectory delimitor in DOS file paths (\ escaped)
 $rc = system('uname > uname.tmp 2>&1');
 unlink ('uname.tmp');
 $OStype = $ENV{'OSTYPE'};	# OSTYPE environment on unix systems (HP/UX excepted)
+$OSname = $ENV{'OS'};
 if ($rc == 0) {
 	$SLASH = $UNIXSLASH;		# subdirectory delimitor in file paths
 	$COPY_COMMAND = 'cp -p';	# unix copy file command
 	$DIFF_COMMAND = 'diff -b';	# unix difference command
 	$ERASE_COMMAND = 'rm -f';	# unix delete file command
 	$XSUFX = '';		# no special suffix for executable module
-	if ($OStype eq 'cygwin32') {
+	$UNAMERC = open(IP,"uname -a |");
+	$_ = <IP>;
+	chop $_;
+	($LINonWIN,$wd2,$wd3,$wd4,$wd5,$wd6,$wd7,$wd8,$wd9) = split(' ',$_);
+	close IP;
+	$LINonWIN =~ m/(.*)(-)([0-9]+\.[0-9]+)/;
+	$LINonWIN = $1 if ($& ne '');	# cleanup version number and keep plain uname
+	if ($OSname eq 'Windows_NT' && $LINonWIN eq 'CYGWIN_NT') {
+# cygwin shell works like a normal unix system
+		$PERLSLASH = $UNIXSLASH;	# subdirectory delimitor for perl file paths
+		$PLSUFX = '.pl';		# no special suffix for perl script
+		}
+	if ($OStype eq '' && $LINonWIN eq '') {
 # since perl for Windows NT is not a PGI Workstation command (cygwin32) but a
 # DOS module, calling the fldiff perl script by means of the "system" function
 # requires DOS conventions
@@ -83,7 +116,7 @@ if ($rc == 0) {
 # When 'uname' command is unknown, the return code is non zero. Under Windows it may
 # be 1 or 256 depending of the Perl version and the command interpretor; check OS
 # environmental variable
-elsif (($rc == 1 || $rc == 256) && $ENV{'OS'} eq 'Windows_NT') {			
+elsif (($rc == 1 || $rc == 256) && $OSname eq 'Windows_NT') {			
 	$OStype = $ENV{'OS'};
 	$SLASH = $DOSSLASH;		# subdirectory delimitor in DOS file paths
 	$COPY_COMMAND = 'copy';		# DOS copy file command
@@ -100,12 +133,20 @@ else {
 	exit 99;
 	}
 
-$CODE_SEQ = &perlpath("$abinit_bindir/abinis$XSUFX");	# codename for sequential version
-$CODE_PAR = &perlpath("$abinit_bindir/abinip$XSUFX");	# codename for parallel version
+
+if ($timeout eq '0') {
+  $timeout_cmd = '';
+  }
+else {
+  $timeout_cmd = &perlpath("$nightly_bindir/timeout$XSUFX")." $timeout ";
+}
+$CODE_SEQ = &perlpath("$abinit_bindir/abinit$XSUFX");	# codename for sequential version
+$CODE_PAR = &perlpath("$abinit_bindir/abinit$XSUFX");	# codename for parallel version
 $PSPS = &transpath($abinit_pspdir);		# pseudopotential directory  
-# Set a default for the second pseudopotential (the latter is needed
-# only for the tests number E and H)
+# Set a default for the second and third pseudopotentials (the latter is needed
+# only for the tests number L)
 $PSP2 = &transpath("$PSPS/33as.SGS_mod");
+$PSP3 = &transpath("$PSPS/33as.SGS_mod");
 $FLDIFF = &perlpath("$PERL $abinit_rundir/fldiff.pl");	# fldiff script in utilities directory
 #*****************************************************************************
  
@@ -116,6 +157,7 @@ $FLDIFF = &perlpath("$PERL $abinit_rundir/fldiff.pl");	# fldiff script in utilit
 # The following characteristics are adapted for machines where neither lam
 # nor mpich have to be used, and where there is always one thread per PE.
 $MACH = $ARGV[0];
+$TESTDIR = $ARGV[1];
 $LAM = 0;
 $MPICH = 0;
 # List the set of cases for each machine (mask the second characteristics
@@ -181,114 +223,20 @@ elsif ($MACH eq 'tux') {
         print FILE $MACH9;
 	close (FILE);
 	}
-#-----------------------------------
-# For the cluster of DEC/Linux "boop" machine at the UCL.
-# Note that on this cluster, the local
-# node (tux0) is used for the first thread.
-# This explains why the number of lines
-# of the cluster files is smaller than usual. 
-# 
-elsif ($MACH eq 'boop') {
+#--------------------------------------
+#
+elsif ($MACH eq 'magerit') {
   $MPICH = 1;
-  $MPICH_DIR = '/usr/local/mpi/bin';
-  $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
-  $MACH1='tux0'; 
-  $MACH2='boop1';
-  $MACH3='boop2';
-  $MACH4='boop3';
-  unlink 'cluster1','cluster2','cluster4','cluster10';
-        open (FILE,">cluster1") || die "Unable to open FILE cluster1";
-        print FILE $MACH1;
-        close (FILE);
-        open (FILE,">cluster2") || die "Unable to open FILE cluster2";
-        print FILE $MACH2;
-        close (FILE);
-        open (FILE,">cluster4") || die "Unable to open FILE cluster4";
-        print FILE $MACH2;
-        print FILE $MACH2;
-        print FILE $MACH2;
-        close (FILE);
-        open (FILE,">cluster10") || die "Unable to open FILE cluster10";
-        print FILE $MACH2;
-        print FILE $MACH2;
-        print FILE $MACH2;
-        print FILE $MACH2;
-        print FILE $MACH2;
-        print FILE $MACH2;
-        print FILE $MACH2;
-        print FILE $MACH2;
-        print FILE $MACH2;
-        close (FILE);
-        }
-#-----------------------------------
-# For the cluster of Intel/Linux machine at the UCL.
-# The syntax for the execution of the parallel run is different
-# from other machines (see the modifs related to "cox" throughout
-# Warning : cox10 had a problem
-elsif ($MACH eq 'cox') {
-  $MPICH = 1;
-  $MPICH_DIR = '/usr/local/mpi/bin';
-  $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
-  $MACH1 = 'cox3.pcpm.ucl.ac.be';
-  $MACH2 = 'cox11.pcpm.ucl.ac.be';
-  $MACH3 = 'cox12.pcpm.ucl.ac.be';
-  $MACH4 = 'cox14.pcpm.ucl.ac.be';
-  $MACH5 = 'cox15.pcpm.ucl.ac.be';
-  unlink 'cluster1','cluster2','cluster4','cluster10';
-	open (FILE,">cluster1") || die "Unable to open FILE cluster1";
-	print FILE '1';
-	print FILE "$MACH1 2";
-	close (FILE);
-	open (FILE,">cluster2") || die "Unable to open FILE cluster2";
-	print FILE '2';
-	print FILE "$MACH1 2";
-	print FILE "$MACH2 2";
-	close (FILE);
-	open (FILE,">cluster4") || die "Unable to open FILE cluster4";
-	print FILE '4';
-	print FILE "$MACH1 2";
-	print FILE "$MACH2 2";
-	print FILE "$MACH3 2";
-	print FILE "$MACH4 2";
-	close (FILE);
-	open (FILE,">cluster10") || die "Unable to open FILE cluster10";
-	print FILE '10';
-	print FILE "$MACH1 2";
-	print FILE "$MACH1 4";
-	print FILE "$MACH2 2";
-	print FILE "$MACH2 4";
-	print FILE "$MACH3 2";
-	print FILE "$MACH3 4";
-	print FILE "$MACH4 2";
-	print FILE "$MACH4 4";
-	print FILE "$MACH5 2";
-	print FILE "$MACH5 4";
-	close (FILE);
-	}
-#-----------------------------------
-# For the IBM 44P machine at the PCPM lab, using MPICH
-elsif ($MACH eq 'ibm_44p') {
-  $MPICH = 1;
-  $MPICH_DIR = '/usr/local/mpi/bin';
-  $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
-  $MACH1 = 'dirac';
+  $MPIRUN_NP = "mpirun -np";
+  $LL_MACHINE_LIST = $ENV{'LL_MACHINE_LIST'};
   $CASE10 = 0;
   unlink 'cluster1','cluster2','cluster4';
-	open (FILE,">cluster1") || die "Unable to open FILE cluster1";
-	print FILE $MACH1;
-	close (FILE);
-	open (FILE,">cluster2") || die "Unable to open FILE cluster2";
-	print FILE $MACH1;
-	print FILE $MACH1;
-	close (FILE);
-	open (FILE,">cluster4") || die "Unable to open FILE cluster4";
-		for ($i = 0; $i < 4; $i++) {
-		print FILE $MACH1;
-		}
-	close (FILE);
+	system("head -1 $LL_MACHINE_LIST > cluster1");
+	system("head -2 $LL_MACHINE_LIST > cluster2");
+	system("head -4 $LL_MACHINE_LIST > cluster4");
 	}
 #-----------------------------------
-# For the IBM Power 5  machine at the PCPM lab, using MPICH
+# For the iBM Power 5  machine at the PCPM lab, using MPICH
 elsif ($MACH eq 'fock') {
   $MPICH = 2;
   $OPENMPI = 1;
@@ -328,12 +276,6 @@ elsif ($MACH eq 'lemaitre') {
   $MPIRUN_NP = '/usr/local/mpich-1.2.6-eth-intel9.1/bin/mpirun -np';
         }
 #-----------------------------------
-# For the HP exemplar, S-Class and N4000
-elsif ($MACH eq 'hp') {
-  $MPIRUN_NP = 'mpirun -j -np';
-  $CASE10 = 0;
-	}
-#-----------------------------------
 # For the Hitachi SR8000
 elsif ($MACH eq 'sr8k' || $MACH eq 'mpd') {
   $MPIRUN_NP = 'mpiexec -n';
@@ -357,27 +299,6 @@ elsif ($MACH eq 'spinoza') {
   $CASE10 = 0;
         }
 #-----------------------------------
-# For the Intel PC XEON "dummy" 2 procs (with hyperthreading)
-elsif ($MACH eq 'dummy') {
-  $MPICH = 1;
-  $MPICH_DIR = '/usr/local/mpi-pgi/bin';
-  $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
-  $MACH0='dummy.pcpm.ucl.ac.be';
-  $MACH1='dummy.pcpm.ucl.ac.be:4';
-  $MACH2='dummy.pcpm.ucl.ac.be:2';
-  $CASE10 = 0;
-  unlink 'cluster1','cluster2','cluster4';
-        open (FILE,">cluster1") || die "Unable to open FILE cluster1";
-        print FILE $MACH1;
-        close (FILE);
-        open (FILE,">cluster2") || die "Unable to open FILE cluster2";
-        print FILE $MACH2;
-        close (FILE);
-        open (FILE,">cluster4") || die "Unable to open FILE cluster4";
-        print FILE $MACH1;
-        close (FILE);
-        }
-#-----------------------------------
 # For the Intel PC XEON "sleepy" 2 procs (with hyperthreading)
 elsif ($MACH =~ /^sleepy-?(.*)/) {
   $MPICH = 1;
@@ -431,6 +352,24 @@ elsif ($MACH eq 'bigmac') {
         close (FILE);
         }
 #-----------------------------------
+# For the MacPro Mac OS X Leopard Server "bigmac" with biprocs Quad-Core Xeon 2.6Ghz (6Gb RAM)
+elsif ($MACH eq 'bigmac-gcc44') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = '/opt/openmpi-1.4.1_gcc-4.4.3_m64/bin';
+  $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
+  $CASE10 = 0;
+}
+#-----------------------------------
+# For the MacPro Mac OS X Leopard Server "bigmac" with biprocs Quad-Core Xeon 2.6Ghz (6Gb RAM)
+elsif ($MACH eq 'bigmac-g95') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = '/usr/local/openmpi_g95/bin';
+  $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
+  $CASE10 = 0;
+}
+#-----------------------------------
 # For the  DELL cluster "green" with biprocs Quad-Core Xeon 2.6Ghz (8Gb RAM) per node
 elsif ($MACH eq 'green') {
   $MPICH = 2;
@@ -454,6 +393,38 @@ elsif ($MACH eq 'green') {
         close (FILE);
         }
 #-----------------------------------
+# For the  DELL cluster "green-gcc42" with biprocs Quad-Core Xeon 2.6Ghz (8Gb RAM) per node
+elsif ($MACH eq 'green-gcc42') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = '/cvos/shared/apps/openmpi/gcc/64/1.3.1/bin';
+  $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
+  $MACH0='green';
+  $MACH1='green';
+  $MACH2='green:2';
+  $MACH3='green:4';
+  $CASE10 = 0;
+  unlink 'cluster1','cluster2','cluster4';
+        open (FILE,">cluster1") || die "Unable to open FILE cluster1";
+        print FILE $MACH1;
+        close (FILE);
+        open (FILE,">cluster2") || die "Unable to open FILE cluster2";
+        print FILE $MACH2;
+        close (FILE);
+        open (FILE,">cluster4") || die "Unable to open FILE cluster4";
+        print FILE $MACH3;
+        close (FILE);
+        }
+#-----------------------------------
+# For the  DELL cluster "green-g95" with biprocs Quad-Core Xeon 2.6Ghz (8Gb RAM) per node
+elsif ($MACH eq 'green-g95') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = '/home/pcpm/buildbot/openmpi/bin';
+  $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
+  $CASE10 = 0;
+}
+#-----------------------------------
 # For the AMD SUN GALAXY X4200  "chum" 2 x AMD 2220 Dual Cores with OpenMPI or MPICH2
 elsif ($MACH =~ /^chum-?(.*)/) {
   $MPICH = 2;
@@ -488,6 +459,134 @@ print "The $MPICH_DIR will be used...($OPENMPI)";
         close (FILE);
 }
 #-----------------------------------
+# For the  2 x Quad Xeon Nehalem 2.6GHz / 12GB  intel11 openmpi 1.3.x
+elsif ($MACH eq 'buda-intel11') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi_intel11/bin/mpirun --mca btl tcp,self -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  2 x Quad Xeon Nehalem 2.6GHz / 12GB  gcc434 + mpich2
+elsif ($MACH eq 'buda_mpich2') {
+  $MPICH = 2;
+  $OPENMPI = 0;
+  $MPICH_DIR = "/usr/local/mpich2/bin";
+  $MPIRUN_NP = '/usr/local/mpich2/bin/mpiexec -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  1 x Intel Core2 Quad CPU 2.6GHz / 4GB  gcc451 + mpich2 + atlas
+elsif ($MACH eq 'littlebuda') {
+  $MPICH = 2;
+  $OPENMPI = 0;
+  $MPICH_DIR = "/usr/local/mpich2/bin";
+  $MPIRUN_NP = '/usr/local/mpich2/bin/mpiexec -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  1 x Intel Core2 Quad CPU 3GHz / 4GB  gcc442 + mpich2
+elsif ($MACH eq 'inca') {
+  $MPICH = 2;
+  $OPENMPI = 0;
+  $MPICH_DIR = "/usr/local/mpich2/bin";
+  $MPIRUN_NP = '/usr/local/mpich2/bin/mpiexec -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  1 x Intel Core2 Quad CPU 3GHz / 8GB  gcc451 + mpich2-1.3
+elsif ($MACH eq 'shiva') {
+  $MPICH = 2;
+  $OPENMPI = 0;
+  $MPICH_DIR = "/usr/local/mpich2/bin";
+  $MPIRUN_NP = '/usr/local/mpich2/bin/mpiexec -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the IBM6  1 x Power6 Quad core 4.7GHz / 8GB  xlf 12 + POE
+elsif ($MACH eq 'ibm6') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $POE = 1;
+  $timeout_cmd = '';
+  $MPIRUN_NP = '/usr/lpp/ppe.poe/bin/poe ';
+#  $MPIRUN_NP = '/usr/bin/mpiexec -hfile /usr/local/etc/host.list -n';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  1 x Power6 Quad core 4.7GHz / 8GB  xlf 12 + mpich2
+elsif ($MACH eq 'ibm6_mpich2') {
+  $MPICH = 2;
+  $OPENMPI = 0;
+  $MPIRUN_NP = '/usr/local/mpich2/bin/mpiexec -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  1 x Power6 Quad core 4.7GHz / 8GB  xlf 12 + openmpi 1.4.x
+elsif ($MACH eq 'ibm6_openmpi') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi/bin/mpirun --mca btl sm,tcp,self -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  2 x Quad Xeon Nehalem 2.6GHz / 12GB  gcc434 + openmpi 1.3.4
+elsif ($MACH eq 'buda-gcc43_openmpi') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi_gcc43/bin/mpirun --mca btl tcp,self -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the  2 x Quad Xeon Nehalem 2.6GHz / 12GB  gcc444 + openmpi 1.4.2
+elsif ($MACH eq 'buda-gcc44_openmpi') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi_gcc44/bin/mpirun --mca btl tcp,self -np';
+  $CASE10 = 0;
+        }
+#
+#-----------------------------------
+# For the  2 x Quad Xeon Nehalem 2.6GHz / 12GB  gcc451 + openmpi 1.4.2
+elsif ($MACH eq 'buda-gcc45_openmpi') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi_gcc45/bin/mpirun --mca btl tcp,self -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the Bull 2 x Quad Xeon Nehalem 3GHz / 12GB  gcc432 + openmpi 1.2.9
+elsif ($MACH eq 'testf-gcc43') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi-gcc43/bin/mpirun -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the Bull 2 x Quad Xeon Nehalem 3GHz / 12GB gcc440 + openmpi 1.3.2
+elsif ($MACH eq 'testf-gcc44') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi-gcc44/bin/mpirun --mca btl tcp,self -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the HP Z400 1 x Quad Xeon Nehalem 2.7GHz / 3GB gcc44 + openmpi 1.3.3
+elsif ($MACH eq 'coba2-gcc44') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi_gcc44/bin/mpirun --mca btl tcp,self -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
+# For the HP Z400 1 x Quad Xeon Nehalem 2.7GHz / 3GB intel11 + openmpi 1.4.1 + mkl +fftw3
+elsif ($MACH eq 'coba2-intel11') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPIRUN_NP = '/usr/local/openmpi_intel/bin/mpirun --mca btl tcp,self -np';
+  $CASE10 = 0;
+        }
+#-----------------------------------
 # For the HP integrity Itanium 4 processor in LLN
 elsif ($MACH eq 'chpit-gcc44') {
   $MPICH = 2;
@@ -527,6 +626,33 @@ elsif ($MACH eq 'pwrg4') {
 #-----------------------------------
 # For the cluster of PowerPC Mac OS X "max" with biprocs
 elsif ($MACH eq 'max') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = '/usr/local/openmpi/bin';
+  $MPIRUN_NP = "$MPICH_DIR/mpirun --mca btl gm,self -np";
+  $MACH0='maxi1 slots=1 max_slots=1';
+  $MACH1='maxi2 slots=1 max_slots=1';
+  $MACH2='maxi3 slots=1 max_slots=1';
+  $MACH3='maxi4 slots=1 max_slots=1';
+  $CASE10 = 0;
+  unlink 'cluster1','cluster2','cluster4';
+        open (FILE,">cluster1") || die "Unable to open FILE cluster1";
+        print FILE $MACH0;
+        close (FILE);
+        open (FILE,">cluster2") || die "Unable to open FILE cluster2";
+        print FILE $MACH0;
+        print FILE $MACH1;
+        close (FILE);
+        open (FILE,">cluster4") || die "Unable to open FILE cluster4";
+        print FILE $MACH0;
+        print FILE $MACH1;
+        print FILE $MACH2;
+        print FILE $MACH3;
+        close (FILE);
+        }
+#-----------------------------------
+# For the cluster of PowerPC Mac OS X "max" with biprocs
+elsif ($MACH eq 'max-eth') {
   $MPICH = 2;
   $OPENMPI = 1;
   $MPICH_DIR = '/usr/local/openmpi-g95/bin';
@@ -554,7 +680,8 @@ elsif ($MACH eq 'max') {
 #-----------------------------------
 # For mpich2-1.0.5p4 (gmatteo@tux)
 elsif ($MACH eq 'mpich2') {
- $MPIRUN_NP = '/opt/mpich2-1.0.5p4/bin/mpirun -np ';
+# $MPIRUN_NP = '/opt/mpich2-1.0.5p4/bin/mpirun -np ';
+ $MPIRUN_NP = '/opt/mpich2-1.2-ifc11/bin/mpirun -np ';
         }
 #-----------------------------------
 # generic
@@ -566,6 +693,19 @@ elsif ($MACH eq 'cea') {
  $MPIRUN_NP = 'cea_mprun -p parallele_128 -n  ';
         }
 #-----------------------------------
+# config
+# parameters extracted from the build system
+elsif ($MACH eq 'config') {
+ $MPIRUN_NP = "$config_mpirun -np ";
+ $CASE4     = 0;
+ $CASE10    = 0;
+        }
+#-----------------------------------
+# For win32_mpich2 i.e. Windows32 with cygwin and mpich2-1.3 (on cauac)
+elsif ($MACH eq 'win32_mpich2') {
+ $MPIRUN_NP = 'mpiexec -np ';
+        }
+#-----------------------------------
 # This is a dummy machine name, for sequential tests only
 # (One should check that this is only used in the sequential case)
 elsif ($MACH eq 'test') {
@@ -582,41 +722,40 @@ print "Testing the Abinit code on the $MACH $OStype platform";
 # Here stop the examination of machine names
 # and the definition of their characteristics
 #*******************************************************************************
-$_ = $ARGV[1];
+$_ = $ARGV[2];
 $hitreport = m/report/;     # check for the keyword report
 if ($hitreport) {
         print "Will make report";
         }
 else {
-        $hitnum = m/[A-Y]/;	# check for upper case
-        $hitrng = m/([A-Y])-(.*)/;	# check for range
+        $hitnum = m/[A-Z]/;	# check for upper case
+        $hitrng = m/([A-Z])-(.*)/;	# check for range
         if ($hitrng) {
 	        $FirstSet = $1;
 	        $LastSet = $2;
 	        $LastSet = '' if ($LastSet eq 'end');
 	        }
         elsif ($hitnum) {	# if last set is omitted, run only first one
-	        $FirstSet = $ARGV[1];
-	        $LastSet = $ARGV[1];
+	        $FirstSet = $ARGV[2];
+	        $LastSet = $ARGV[2];
 	        }
         else {
-	        print "Invalid sets: $ARGV[1]";
+	        print "Invalid sets: $ARGV[2]";
 	        exit 24;
 	        }
-
 # set label for default first and last test number
-        $FirstCase = '0';
+        $FirstCase = '1';
         $LastCase = '10';
-        $_ = $ARGV[2];
+        $_ = $ARGV[3];
         $hit = m/(.*)-(.*)/;	# check for range
 	        if ($hit) {
 		        $FirstCase = $1;
 		        $LastCase = $2;
 		        $LastCase = '10' if ($LastCase eq 'end');
 		        }
-	        elsif ($ARGV[2] ne '') {	# if last test is omitted, run only first one
-		        $FirstCase = $ARGV[2];
-		        $LastCase = $ARGV[2];
+	        elsif ($ARGV[3] ne '') {	# if last test is omitted, run only first one
+		        $FirstCase = $ARGV[3];
+		        $LastCase = $ARGV[3];
 		        }
 
         print "Following tests will be run: sets $FirstSet to $LastSet, cases $FirstCase to $LastCase";
@@ -630,7 +769,7 @@ $ymon++;	# ymon was 0-11
 $yyear +=1900;	# yyear was relative to 1900
 $YYYYMMDD = sprintf("%4.4d",$yyear).sprintf("%2.2d",$ymon).sprintf("%2.2d",$mday);
 
-$WORK_DIR = ',,'.$MACH.'_'.$YYYYMMDD;
+$WORK_DIR = 'tmp-'.$MACH.'_'.$YYYYMMDD;
 if (! -e $WORK_DIR || ! -d $WORK_DIR) {
 	mkdir ($WORK_DIR,0755);		# Mode 0755 ignored under DOS-Windows
 	}
@@ -650,6 +789,7 @@ if ($hitreport) {
 # **************************************** 
 # Loop on all the sets
 for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
+        last if ($T1 eq 'AA');
 # Make preliminary operations that might differ for different tests
 
 # HERE, the set of possible tests and corresponding input file
@@ -677,8 +817,8 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 	  $PSP1 = "$PSPS/13al.pspgth";
           $PSP2 = "$PSPS/33as.SGS_mod";
 		unlink 'tF.i_DS1_DEN','tF.i_DS2_DEN';
-	  system("$COPY_COMMAND tC0.o_DEN tF.i_DS1_DEN"); 
-	  system("$COPY_COMMAND tC0.o_DEN tF.i_DS2_DEN"); 
+	  system("$COPY_COMMAND tC1.o_DEN tF.i_DS1_DEN"); 
+	  system("$COPY_COMMAND tC1.o_DEN tF.i_DS2_DEN"); 
 	  }
 #
 	elsif ($T1 eq 'G') {
@@ -686,8 +826,8 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
           $PSP2 = "$PSPS/33as.SGS_mod";
 	  $OPTFLDIFF = '-medium';
 	  unlink 'tG.i_WFK','tG.i_WFQ';
-	  system("$COPY_COMMAND tC0.o_WFK tG.i_WFK");
-	  system("$COPY_COMMAND tC0.o_WFK tG.i_WFQ");
+	  system("$COPY_COMMAND tC1.o_WFK tG.i_WFK");
+	  system("$COPY_COMMAND tC1.o_WFK tG.i_WFQ");
 	  }
 #
 	elsif ($T1 eq 'I') {
@@ -697,22 +837,24 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 	  }
 #
         elsif ($T1 eq 'K') {
-          $PSP1 = "$PSPS/31ga.pspnc";
-          $PSP2 = "$PSPS/33as.pspnc";
-          $OPTFLDIFF = '-medium';
+          $PSP1 = "$PSPS/7n.psphgh";
           }
 #
         elsif ($T1 eq 'L') {
-          $PSP1 = "$PSPS/7n.pspnc";
-          $PSP2 = "$PSPS/14si.pspnc";
+          $PSP1 = "$PSPS/41nb_001023.pspfhi";
+          $PSP2 = "$PSPS/03li.pspfhi";
+          $PSP3 = "$PSPS/08o_001023.pspfhi";
+          $OPTFLDIFF = '-medium';
           }
 #
         elsif ($T1 eq 'M') {
           $PSP1 = "$PSPS/14si.pspnc";
+          $CASE10=0;
           }
 #
         elsif ($T1 eq 'N') {
           $PSP1 = "$PSPS/14si.pspnc";
+          $CASE10=0;
           }
 #
         elsif ($T1 eq 'O') {
@@ -766,6 +908,7 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 #This is to test the SC-GW with advanced memory management in parallel
         elsif ($T1 eq 'V') {
           $PSP1 = "$PSPS/11na.pspnc";
+          $CASE10=0;
           }
 	$FLDreport = "fldiff.set$T1.report";
 	unlink $FLDreport;
@@ -800,6 +943,14 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 	  $CASE2= 0;
 	  $CASE10=0;
           }
+#Tddft test
+        elsif ($T1 eq 'Z') {
+          $PSP1 = "$PSPS/31ga.pspnc";
+          $PSP2 = "$PSPS/33as.pspnc";
+          $OPTFLDIFF = '-medium';
+
+          $PSP1 = "$PSPS/7n.psphgh";
+          }
 	
 # ****************************************
 	foreach $case (@Cases) {
@@ -814,6 +965,7 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 			last if ($T2 eq $LastCase); 
 			next;
 			}
+		print "\nSet $T1 / Case $T2\n";
 #Set some variables according to the value of $T2
 		$MODE = $T2 eq '0' ? 'SEQ' : 'PAR';
 		$CLUST = "../cluster$T2";
@@ -822,29 +974,49 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 		system ("$ERASE_COMMAND t$T1$T2*");	# unlink with metachar
 #Initialize the files file
 		open (FILE,">$RUNfile") || die "Unable to open FILE $RUNfile";
-		print FILE "$abinit_inpdir/paral/Input/t$T1.in";
+		print FILE "$abinit_inpdir/$TESTDIR/Input/t$T1.in";
 		print FILE "t$T1$T2.out";
 		print FILE "t$T1.i";
 		print FILE "t$T1$T2.o";
 		print FILE "t$T1$T2";
 		print FILE $PSP1;
 		print FILE $PSP2;
+		print FILE $PSP3;
 		close (FILE);
 #Run the job
-		if ($MACH eq 'cox') {
-			$MachFile = "--gm-f $CLUST";
+		if ($MACH eq 'max') {
+			$MachFile = "--hostfile $CLUST";
 			}
 		elsif ($MPICH == 1 && $MODE eq 'PAR') { 
 			$MachFile = "-machinefile $CLUST";
 			}
+		elsif ($POE == 1 ) { 
+			$MachFile = "-hostfile /usr/local/etc/host.list";
+			}
 		else {
 			$MachFile = '';
 			}
 # if not OPENMPI, start mpd (MPICH2)
 		if ($OPENMPI == 0) {
 			$MPDSTAT=`$MPICH_DIR/mpdtrace`;
-			if ( $MPDSTAT =~ !/^chum/ ) {
+			if ( $MACH =~ /^chum/ ) {
+			   if ( $MPDSTAT =~ !/^chum/ ) {
         			system("$MPICH_DIR/mpd &");
+				sleep 3;
+			   }
+			}
+			if ( $MACH =~ /^buda/ ) {
+			   if ( $MPDSTAT =~ !/^buda/ ) {
+        			system("$MPICH_DIR/mpd &");
+				sleep 3;
+			   }
+			}
+# REM : inca use now pm=gforker then no more needs mpd
+			if ( $MACH =~ /^i_nca/ ) {
+			   if ( $MPDSTAT =~ !/^i_nca/ ) {
+        			system("$MPICH_DIR/mpd &");
+				sleep 3;
+			   }
 			}
 		}
 
@@ -855,14 +1027,20 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 		}
 #
 		if ($MODE eq 'SEQ') {
-			$CALL_CODE = ($T2 eq '0' && $MACH eq 'sr8k') ? "prun $CODE_SEQ" : $CODE_SEQ
+			$CALL_CODE = ($T2 eq '0' && $MACH eq 'sr8k') ? "prun $CODE_SEQ" : $CODE_SEQ;
+			$CALL_CODE = $timeout_cmd.$CALL_CODE;
 			}
 		else {
-			$CALL_CODE = $MACH eq 'vpp' ? "$CODE_PAR $MPIRUN_NP $NPAR" : "$MPIRUN_NP $NPAR $MachFile $CODE_PAR"
+			$CALL_CODE = $MACH eq 'vpp' ? "$CODE_PAR $MPIRUN_NP $NPAR" : "$MPIRUN_NP $NPAR $MachFile $CODE_PAR";
+			$CALL_CODE = $MACH eq 'ibm6' ? "$MPIRUN_NP $CODE_PAR $MachFile -procs $NPAR" : "$MPIRUN_NP $NPAR $MachFile $CODE_PAR";
+			$CALL_CODE = $timeout_cmd.$CALL_CODE;
 			}
 		$cmd = "$CALL_CODE < $RUNfile > t$T1$T2.log";
 		print $cmd if ($debug > 1);
 		system($cmd);
+
+		# make sure there exists an output file
+		system("touch t$T1$T2.out");
 #
 		if ($LAM == 1 && $MODE eq 'PAR') {
 		$cmd = "$LAMDIR/wipe $CLUST";
@@ -870,14 +1048,14 @@ for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 		system($cmd);
 		}
 #Analyze the output
-		$cmd = "$DIFF_COMMAND t$T1$T2.out $abinit_inpdir/paral/Refs/t$T1$NPAR.out > diff.t$T1$T2";
+		$cmd = "$DIFF_COMMAND t$T1$T2.out $abinit_inpdir/$TESTDIR/Refs/t$T1$NPAR.out > diff.t$T1$T2";
 		print $cmd if ($debug > 1);
 		system($cmd);
 # append label with test number to report file
 		open (FLDREP,">>$FLDreport") || die "Unable to open FLDREP for test $T1$T2";
 		print FLDREP "\n","Case_$T1$T2";	# Case_NN
 		close (FLDREP);
-		$cmd = "$FLDIFF -ignore $OPTFLDIFF t$T1$T2.out $abinit_inpdir/paral/Refs/t$T1$NPAR.out Case_$T1$T2 >> $FLDreport";
+		$cmd = "$FLDIFF -ignore $OPTFLDIFF t$T1$T2.out $abinit_inpdir/$TESTDIR/Refs/t$T1$NPAR.out Case_$T1$T2 >> $FLDreport";
 		print $cmd if ($debug > 1);
 		system($cmd);
 #Eventually exit
@@ -931,7 +1109,7 @@ sub doreport {
 # $fn4 = auxiliary output file name
 # set default files names derived from $TID:
 # Prepare filenames
-        $fn1 = "$abinit_inpdir/paral/Input/report.in";
+        $fn1 = "$abinit_inpdir/$TESTDIR/Input/report.in";
         $reportref = &transpath($fn1);
         $fn2 = "fldiff.*.report" ;
         $fldiffreport = &transpath($fn2);
@@ -950,82 +1128,3 @@ sub doreport {
         }
 
 # ****************************************
-sub reportdiff {
-        local($fn1,$fn2,$fn3) = @_;
-#
-# purpose : examine $fn1, using the reference values in $fn2, and echo result in $fn3
-#
-        $rc = open(FILEIN,"$fn1");
-        if ($rc eq '') {
-         print "Unable to open input file $fn1\n";
-         }
-        $rc = open(FILEREF,"$fn2");
-        if ($rc eq '') {
-         print "Unable to open input file $fn2\n";
-         }
-        $rc = open (FILEOUT,">>$fn3");
-        if ($rc eq '') {
-         print "Unable to open input file $fn2\n";
-         }
-#       Read both files, one line at a time
-        $lnm1 = 0;
-        $lnm2 = 0;
-        while (1) {
-          $lin1 = <FILEIN>  ;   # read next line from file 1
-          $lin2 = <FILEREF> ;   # read next line from file 2
-          last if($lin1 eq '' && $lin2 eq ''); # end of both files
-          @field1 = split(' ',$lin1);       # parse line into array
-          @field2 = split(' ',$lin2);
-          if ($field1[0] ne 'Summary') {
-            print FILEOUT "Error : all lines of file to be analysed must start with 'Summary' " ;
-            print FILEOUT "Analysed file  $fn1, line $lnm1, gives :" ;
-            print FILEOUT "$lin1" ;
-            print FILEOUT "$field1[0]" ;
-            print FILEOUT "exit" ;
-            exit ;
-            }
-          if ($field1[1] ne $field2[0]) {
-            print FILEOUT "Error : indices of cases do not match in analysed and reference files " ;
-            print FILEOUT "Analysed file  $fn1, line $lnm1, gives $field1[1] ;" ;
-            print FILEOUT "Reference file $fn2, line $lnm2, gives $field2[0] ;" ;
-            print FILEOUT "exit" ;
-            exit ;
-            }
-          if ($field1[3] eq "fatal") {
-            print FILEOUT "$field1[1]            failed" ;
-            }
-          elsif ($field1[3] eq "no") {
-            print FILEOUT "$field1[1] succeeded" ;
-            }
-          elsif ($field1[3] eq "different") {
-            $tolnlines = $field2[2] ;
-            $tolabs = $field2[4] ;
-            $tolrel = $field2[6] ;
-            if ( $field1[10] > $tolabs*1.5 ) {
-              print FILEOUT "$field1[1]            failed (too large absolute error : $field1[10] , accepted $tolabs ) " ;
-              }
-            elsif ( $field1[13] > $tolrel*1.5 ) {
-              print FILEOUT "$field1[1]            failed (too large relative error : $field1[13] , accepted $tolrel ) " ;
-              }
-            elsif ( $field1[5] > $tolnlines ) {
-              print FILEOUT "$field1[1]            failed (too many erroneous lines : $field1[5] , accepted $tolnlines ) " ;
-              }
-            elsif ( $field1[10] > $tolabs ) {
-              print FILEOUT "$field1[1] within 1.5 of tolerance (absolute error : $field1[10] , accepted $tolabs ) " ;
-              }
-            elsif ( $field1[13] > $tolrel ) {
-              print FILEOUT "$field1[1] within 1.5 of tolerance (relative error : $field1[13] , accepted $tolrel ) " ;
-              }
-            else {
-              print FILEOUT "$field1[1] passed" ;
-              }
-            }
-          }
-        close (FILEIN);
-        close (FILEREF);
-        close (FILEOUT);
-        return;                 # go read next line from configuration file
-        }
-
-# ****************************************
-
