@@ -2,8 +2,11 @@
 # Wrapper for the standard tests of abinit
 #
 
+# Init
 my_name="wrap-standard-tests"
-my_cnffile="tests.env"
+
+# The leading './' is essential!
+my_cnffile="./tests.env"
 
 # Check arguments
 if test "${#}" -lt "1"; then
@@ -21,11 +24,14 @@ else
 fi
 
 # Save log if machine_name is chkinabi
-if test "${1}" = "chkinabi"; then
- my_logfile='>& ,,chkinabi.log'
+machine_name="${1}"
+shift
+if test "${machine_name}" = "chkinabi"; then
+ my_logfile='>& tmp-chkinabi.log'
 else
  my_logfile=''
 fi
 
-${PERL} Scripts/run-standard-tests.pl $@ ${my_logfile}
+${PERL} ${abinit_inpdir}/Scripts/run-standard-tests.pl \
+  ${machine_name} $@ ${my_logfile}
 exit ${?}
