@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2009 ABINIT group (XG)
+# Copyright (C) 1998-2010 ABINIT group (XG)
 # 
 # The purpose of this script is to change some
 # expression by another in a whole set of files
@@ -8,7 +8,7 @@ for file in "$@"
 do
  echo "working on $file"
  rm -f tmp.file
- sed -e 's!52_fftnew_!52_fft_!' $file > tmp.file
+ sed -e 's!is available at -!is available at!' $file > tmp.file
  echo "changes done "
  # put the modified file at the correct place
  mv tmp.file $file
