@@ -7,7 +7,7 @@ echo "Looking for OpenMP directives"
 echo "-----------------------------"
 echo ""
 
-for d in prereqs/[a-z]* plugins/[a-z]* src/defs src/[0-9]*
+for d in prereqs/[a-z]* plugins/[a-z]* src/[0-9]*
 do
 	omp_files=""
 
