@@ -1,10 +1,14 @@
 #===================================
 program = 'AbinitBandStructureMaker.py'
-version = '1.2'
+version = '1.3'
 #===================================
-# last modified : march 8 2006
+# last modified : november 16 2010
 # written by Benjamin Tardif
 # benjamin.tardif@umontreal.ca
+# Modified by Paul Boulanger 
+# 1.3 : Converted to numpy
+#     : corrected a bug related to termination of the segments (line 114)
+#     : defined a second angletol to distinguish between specialkpt detection and segment construction
 #===================================
 
 
@@ -13,7 +17,8 @@ version = '1.2'
 import os
 import sys
 import time
-from Numeric import *
+from numpy import *
+#from Numeric import *
 #=====================================================================================================================================================================
 
 
@@ -77,7 +82,8 @@ ctrl.filedata = list()                # list of strings each containing one line
 ctrl.dbsfilename = str()              # name of the file produced (*.dbs)
 ctrl.agrfilename = str()              # name of the file produced (*.agr)
 
-ctrl.angletol = 2                # maximum angle between 2 k-points under which they will be considered being in the same direction
+ctrl.angletol = 1                # maximum angle between 2 k-points under which they will be considered being in the same direction
+ctrl.angletol2 = 0.1
 ctrl.bandstructurescheme = str() # scheme of the type '{lA}-{lB}-{lC}' corresponding to the band structure to be plotted
                                  # each {} corresponds to the name given to a special k-point
                                  # {} 1st character : 'l' for 'letter' or 's' for 'symbol'
@@ -952,7 +958,7 @@ if ctrl.filetype == 'out':
         for i in range(len(dataset)):
             if dataset[i].split()[0][:4] == 'kpt#':
                 linesplit = dataset[i].split()
-                kptlist.append(array([float(linesplit[-5]),float(linesplit[-4]),float(linesplit[-3])],Float))
+                kptlist.append(array([float(linesplit[-5]),float(linesplit[-4]),float(linesplit[-3])],dtype=float))
                 k=i+1
                 energylist = list()
                 while dataset[k].split()[0].replace('-','').replace('.','').replace('e','').replace('E','').isdigit():
@@ -985,6 +991,7 @@ if ctrl.filetype == 'out':
             data.specialkpt.append(data.kpt[i])
         else:
             vector1 = data.kpt[i] - data.kpt[i-1]
+            
             if angle(vector1,vector2) < ctrl.angletol:
                 pass
             else:
@@ -1021,9 +1028,9 @@ if ctrl.filetype == 'dbs':
     for i in range(len(ctrl.filedata)):
         if ctrl.filedata[i].split()[0] == 'reciprocalvectors:':
             linesplit = ctrl.filedata[i].split()
-            data.G.append(array([float(linesplit[1]),float(linesplit[2]),float(linesplit[3])],Float))
-            data.G.append(array([float(linesplit[4]),float(linesplit[5]),float(linesplit[6])],Float))
-            data.G.append(array([float(linesplit[7]),float(linesplit[8]),float(linesplit[9])],Float))
+            data.G.append(array([float(linesplit[1]),float(linesplit[2]),float(linesplit[3])],dtype=float))
+            data.G.append(array([float(linesplit[4]),float(linesplit[5]),float(linesplit[6])],dtype=float))
+            data.G.append(array([float(linesplit[7]),float(linesplit[8]),float(linesplit[9])],dtype=float))
     if ctrl.debugmode==True:
         print '\n--> reciprocal vectors found'
         for i in range(3):
@@ -1045,7 +1052,7 @@ if ctrl.filetype == 'dbs':
         linesplit = ctrl.filedata[i].split()
         if '}=' in linesplit[0] and linesplit[0][0] == '{':
             kptcaption = linesplit[0].split('=')[0]
-            ctrl.dicospecialkpt[kptcaption] = array([float(linesplit[1]),float(linesplit[2]),float(linesplit[3])],Float)
+            ctrl.dicospecialkpt[kptcaption] = array([float(linesplit[1]),float(linesplit[2]),float(linesplit[3])],dtype=float)
     if ctrl.debugmode==True:
         print '\n--> special k-points found\n    %s element(s)' %len(ctrl.dicospecialkpt)
         for i in range(len(ctrl.dicospecialkpt)):
@@ -1064,7 +1071,7 @@ if ctrl.filetype == 'dbs':
     for i in range(len(ctrl.filedata)):
         if ctrl.filedata[i].split()[0] == 'kpt':
             linesplit = ctrl.filedata[i+1].split()
-            data.kpt.append(array([float(linesplit[0]),float(linesplit[1]),float(linesplit[2])],Float))
+            data.kpt.append(array([float(linesplit[0]),float(linesplit[1]),float(linesplit[2])],dtype=float))
             energieslist = list()
             for energy in ctrl.filedata[i+2].split():
                 energieslist.append(float(energy))
@@ -1168,7 +1175,7 @@ if ctrl.filetype == 'dbs':
                 elif list(kpt)==list(kf):
                     goodkpt = True
                     xfrac=1
-                elif angle(kpt-ki,kf-ki) < ctrl.angletol:
+                elif angle(kpt-ki,kf-ki) < ctrl.angletol2 and dot(kf-kpt,kf-ki) > 0.0:
                     goodkpt = True
                     xfrac=dot(kpt-ki,kf-ki)/norm(kf-ki)/norm(kf-ki)
                 if goodkpt == True:
